@@ -1,5 +1,5 @@
 ## File Name: bct_regression.R
-## File Version: 0.172
+## File Version: 0.173
 
 
 bct_regression <- function( formula, data, weights=NULL,
@@ -7,7 +7,7 @@ bct_regression <- function( formula, data, weights=NULL,
     use_grad=2, h=1E-5, optimizer="optim", maxiter=300, control=NULL )
 {
     CALL <- match.call()
-    type <- "bct"
+    type <- 'bct'
     #--- wrapping general regression function
     res <- mdmb_regression( formula=formula, data=data, type=type,
                 weights=weights, beta_init=beta_init, beta_prior=beta_prior,
