@@ -1,11 +1,11 @@
 ## File Name: fit_mdmb_distribution_logLik_extract.R
-## File Version: 0.09
+## File Version: 0.101
 
 fit_mdmb_distribution_logLik_extract <- function( object )
 {
     out <- - object$deviance / 2
-    attr(out, "df") <- object$np
-    attr(out, "nobs") <- object$N
-    class(out) <- "logLik"
+    attr(out, 'df') <- object$np
+    attr(out, 'nobs') <- object$N
+    class(out) <- 'logLik'
     return(out)
 }
