@@ -1,9 +1,9 @@
 ## File Name: fit_mdmb_distribution_summary_table.R
-## File Version: 0.21
+## File Version: 0.221
 
 fit_mdmb_distribution_summary_table <- function( beta, vcov1 )
 {
-    dfr <- data.frame( "parm"=names(beta) )
+    dfr <- data.frame(parm=names(beta) )
     dfr$est <- beta
     dfr$se <- sqrt( diag(vcov1) )
     quant <- stats::qnorm(.975)
