@@ -1,5 +1,5 @@
 ## File Name: frm_em.R
-## File Version: 0.966
+## File Version: 0.972
 
 
 frm_em <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
@@ -37,7 +37,7 @@ frm_em <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
     N2 <- nrow(dat)
 
     #*** prepare list of models
-    NM <- attr(ind,"NM")
+    NM <- attr(ind,'NM')
     if (is.null(update_model)){
         ind0 <- ind
         ind0[[ dep$dv_vars ]] <- dep
@@ -49,7 +49,6 @@ frm_em <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
         weights0 <- update_model$weights0
     }
 
-
     iter <- 0
     conv <- FALSE
     ll_new <- 1E-500
@@ -80,10 +79,10 @@ frm_em <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
         if (iter==1 ){ ll_change_disp <- NA }
         beta_change <- max( abs( beta_new - beta_old ) )
         if(verbose){
-            p1 <- paste0("*** Iter. ", iter, " | ", "LL ","=", " ",
+            p1 <- paste0('*** Iter. ', iter, ' | ', 'LL ','=', ' ',
                     round(ll_new,3),
-                    " | LL change ", "=", " ", round(ll_change_disp,6),
-                    " | Parm. change ", "=", " ", round(beta_change,6),"\n"    )
+                    ' | LL change ', '=', ' ', round(ll_change_disp,6),
+                    ' | Parm. change ', '=', ' ', round(beta_change,6),'\n'    )
             cat(p1)
             utils::flush.console()
         }
@@ -100,10 +99,10 @@ frm_em <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
 
     }
     #***************************************
-#    cat("\n* EM algorithm ") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
+#    cat('\n* EM algorithm ') ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1
 
     if (verbose){
-        cat("--- Compute asymptotic covariance matrix")
+        cat('--- Compute asymptotic covariance matrix')
         utils::flush.console()
     }
 
@@ -111,7 +110,7 @@ frm_em <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
     res0 <- frm_em_avcov(res=res, dat=dat, ind0=ind0, NM=NM, h=h)
 
     if (verbose){
-        cat("\n")
+        cat('\n')
         utils::flush.console()
     }
 
@@ -140,8 +139,8 @@ frm_em <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
                 model_results=res$model_results, like0=res$like0,
                 freq_miss_values=freq_miss_values, weights0=weights0,
                 CALL=CALL, s1=s1, s2=s2    , diff_time=s2-s1    )
-    class(res) <- "frm_em"
+    class(res) <- 'frm_em'
     return(res)
 }
 
-# z0 <- TAM:::tamcat("calc_likelihood",z0,TRUE)
+# z0 <- TAM:::tamcat('calc_likelihood',z0,TRUE)
