@@ -1,5 +1,5 @@
 ## File Name: frm_em_calc_likelihood_estimate_model.R
-## File Version: 0.459
+## File Version: 0.461
 
 frm_em_calc_likelihood_estimate_model <- function( ind_mm, dat, weights )
 {
@@ -7,11 +7,11 @@ frm_em_calc_likelihood_estimate_model <- function( ind_mm, dat, weights )
     R_args <- frm_append_list(list1=R_args, list2=ind_mm$R_args)
     R_fct <- ind_mm$R_fct
     #--- linear regression
-    is_linreg <- ind_mm$model=="linreg"
+    is_linreg <- ind_mm$model=='linreg'
     if ( is_linreg ){
         R_args <- ind_mm$R_des
-        R_args[["w"]] <- weights
-        R_fct <- "mdmb_lm_wfit"
+        R_args[['w']] <- weights
+        R_fct <- 'mdmb_lm_wfit'
     }
     #-- estimate regression model
     mod <- do.call( what=R_fct, args=R_args )
@@ -24,4 +24,4 @@ frm_em_calc_likelihood_estimate_model <- function( ind_mm, dat, weights )
 }
 
 # z0 <- Sys.time()
-# z0 <- TAM:::tamcat(" ** weighted_sd",z0,TRUE)
+# z0 <- TAM:::tamcat(' ** weighted_sd',z0,TRUE)
