@@ -1,9 +1,9 @@
 ## File Name: frm_em_linreg_density_extend_args.R
-## File Version: 0.04
+## File Version: 0.051
 
 frm_em_linreg_density_extend_args <- function(args, ind_mm)
 {
-    if (ind_mm$model=="linreg"){
+    if (ind_mm$model=='linreg'){
         args$X <- ind_mm$R_des$x
         args$offset <- ind_mm$R_des$offset
     }
