@@ -1,5 +1,5 @@
 ## File Name: frm_fb_init_imputations.R
-## File Version: 0.490
+## File Version: 0.492
 
 frm_fb_init_imputations <- function( Nimp, model_results, burnin, iter, impute_vars,
         impute_vars_index, ind_miss, ind0, dv_vars,    variablesMatrix, dat=NULL )
@@ -8,7 +8,7 @@ frm_fb_init_imputations <- function( Nimp, model_results, burnin, iter, impute_v
     imp_save <- round( seq( burnin + 1, iter, length=Nimp ) )
     NV <- length(impute_vars)
     #--- objects for imputed values
-    values <- as.list( 1:NV )
+    values <- as.list( 1L:NV )
     names(values) <- impute_vars
     mh_imputations_values <- values
     impute_vars_models <- values
@@ -16,27 +16,26 @@ frm_fb_init_imputations <- function( Nimp, model_results, burnin, iter, impute_v
     sampling_level <- cluster_index
     use_sampling_level <- as.list( rep(NA, NV) )
 
-    for (vv in 1:NV){
-        # vv <- 1
+    for (vv in 1L:NV){
         var_vv <- impute_vars[vv]
         N_vv <- length(ind_miss[[ var_vv ]])
         #**** matrices for imputed values
         values[[var_vv]] <- matrix( NA, nrow=N_vv, ncol=Nimp )
         #*** informations for MH sampling
         M1 <- matrix( 0, nrow=N_vv, ncol=3 )
-        colnames(M1) <- c("accepted", "iter", "sd_proposal")
+        colnames(M1) <- c('accepted', 'iter', 'sd_proposal')
         M1 <- as.data.frame(M1)
         mm <- which( var_vv==dv_vars )
         model_mm <- ind0[[mm]]$model
-        if ( model_mm %in% c("bctreg","yjtreg","linreg") ){
+        if ( model_mm %in% c('bctreg','yjtreg','linreg') ){
             parm <- ind0[[mm]]$coef
             # parm <- mdmb_extract_coef(mod=ind0[[mm]])
             np <- length(parm)
-            if ( model_mm=="linreg" ){
+            if ( model_mm=='linreg' ){
                 ind_sigma <- np + 1
                 parm <- c( parm, ind0[[mm]]$sigma )
             }
-            if ( model_mm %in% c("bctreg","yjtreg") ){
+            if ( model_mm %in% c('bctreg','yjtreg') ){
                 ind_sigma <- np - 1
                 est_df <- ind0[[mm]]$R_args$est_df
                 if ( ! is.null(est_df) ){
@@ -47,7 +46,7 @@ frm_fb_init_imputations <- function( Nimp, model_results, burnin, iter, impute_v
             }
             ind0[[mm]]$sigma <- parm[ ind_sigma ]
         }
-        if ( model_mm %in% c("mlreg") ){
+        if ( model_mm %in% c('mlreg') ){
             ind0[[mm]]$sigma <- sqrt( model_results[[mm]]$sigma2 )
         }
         M1$sd_proposal <- ind0[[mm]]$sigma
