@@ -1,5 +1,5 @@
 ## File Name: frm_oprobit_density.R
-## File Version: 0.17
+## File Version: 0.181
 
 frm_oprobit_density <- function(model, y, design_matrix=NULL, case=NULL)
 {
@@ -12,6 +12,6 @@ frm_oprobit_density <- function(model, y, design_matrix=NULL, case=NULL)
     thresh <- logthresh_2_thresh(x=logthresh)
     d1 <- mdmb_regression_oprobit_density( y=y, ypred=y_pred, thresh=thresh, log=FALSE)
     d2 <- frm_normalize_posterior( post=d1, case=case )
-    res <- list( "like"=d1, "post"=d2 )
+    res <- list( like=d1, post=d2 )
     return(res)
 }
