@@ -1,11 +1,11 @@
 ## File Name: frm_prepare_models_sigma_fixed.R
-## File Version: 0.14
+## File Version: 0.151
 
 frm_prepare_models_sigma_fixed <- function( ind0, NM, dat0, dat)
 {
     NM1 <- NM + 1
     N <- nrow(dat0)
-    for (mm in 1:NM1){
+    for (mm in 1L:NM1){
         # mm <- 1
         ind_mm <- ind0[[mm]]
         sigma_fixed <- ind_mm$sigma_fixed
