@@ -1,11 +1,11 @@
 ## File Name: logLik_extract_ic.R
-## File Version: 0.06
+## File Version: 0.071
 
 logLik_extract_ic <- function( object )
 {
     out <- - object$ic$deviance / 2
-    attr(out, "df") <- object$ic$np
-    attr(out, "nobs") <- object$ic$n
-    class(out) <- "logLik"
+    attr(out, 'df') <- object$ic$np
+    attr(out, 'nobs') <- object$ic$n
+    class(out) <- 'logLik'
     return(out)
 }
