@@ -1,5 +1,5 @@
 ## File Name: logistic_regression.R
-## File Version: 0.58
+## File Version: 0.591
 
 
 logistic_regression <- function( formula, data, weights=NULL,
@@ -7,8 +7,8 @@ logistic_regression <- function( formula, data, weights=NULL,
     optimizer="optim", maxiter=300, control=NULL )
 {
     CALL <- match.call()
-    type <- "logistic"
-    #--- wrapping general regression function
+    type <- 'logistic'
+    #--- wrapper to general regression function
     res <- mdmb_regression( formula=formula, data=data, type=type,
                 weights=weights, beta_init=beta_init,
                 use_grad=use_grad, h=h, beta_prior=beta_prior,
