@@ -1,9 +1,9 @@
 ## File Name: mdmb_extract_coef.R
-## File Version: 0.02
+## File Version: 0.03
 
 mdmb_extract_coef <- function(mod)
 {
-    if ("coef" %in% names(mod) ){
+    if ('coef' %in% names(mod) ){
         c1 <- mod$coef
     } else {
         c1 <- mod$coefficients
