@@ -1,5 +1,5 @@
 ## File Name: mdmb_optim_control.R
-## File Version: 0.03
+## File Version: 0.06
 
 mdmb_optim_control <- function(optimizer, control, maxiter)
 {
@@ -7,9 +7,13 @@ mdmb_optim_control <- function(optimizer, control, maxiter)
         control <- list()
     }
     #*** stats::optim
-    if (optimizer=="optim"){ maxit_label <- "maxit" }
+    if (optimizer=='optim'){
+        maxit_label <- 'maxit'
+    }
     #*** stats::nlminb
-    if (optimizer=="nlminb"){ maxit_label <- "iter.max" }
+    if (optimizer=='nlminb'){
+        maxit_label <- 'iter.max'
+    }
     #*** maximum number of iterations
     if (is.null(control[[maxit_label]]) ){
         control[[maxit_label]] <- maxiter
