@@ -1,13 +1,13 @@
 ## File Name: mdmb_regression_extract_parameters.R
-## File Version: 0.12
+## File Version: 0.131
 
 mdmb_regression_extract_parameters <- function( mod, parnames, type,
     is_lambda_fixed, lambda_fixed)
 {
     beta <- mod$par
-    if ( ( type %in% c("yjt","bct") ) & ( is_lambda_fixed ) ){
+    if ( ( type %in% c('yjt','bct') ) & ( is_lambda_fixed ) ){
         beta <- c( beta, lambda_fixed )
-        parnames <- c(parnames, "lambda" )
+        parnames <- c(parnames, 'lambda' )
     }
     names(beta) <- parnames
     return(beta)
