@@ -1,5 +1,5 @@
 ## File Name: mdmb_regression_loglike_case.R
-## File Version: 0.19
+## File Version: 0.201
 
 #**** evaluate individual likelihood
 mdmb_regression_loglike_case <- function(y, linear.predictor,
@@ -8,12 +8,12 @@ mdmb_regression_loglike_case <- function(y, linear.predictor,
     np <- length(beta)
     #**********************
     # logistic regression
-    if (type=="logistic"){
+    if (type=='logistic'){
         loglike_case <- ifelse( y==1, fitted.values, 1 - fitted.values )
     }
     #**********************
     # ordinal probit model
-    if (type=="oprobit"){
+    if (type=='oprobit'){
         thresh <- logthresh_2_thresh(x=beta[ index_thresh ])
         loglike_case <- mdmb_regression_oprobit_density( y=y, ypred=linear.predictor,
                             thresh=thresh, log=FALSE )
@@ -21,7 +21,7 @@ mdmb_regression_loglike_case <- function(y, linear.predictor,
 
     #**********************
     # yjt regression
-    if (type=="yjt"){
+    if (type=='yjt'){
         sigma <- beta[ np-1 ]
         lambda <- beta[ np ]
         loglike_case <- dyjt_scaled( y, location=linear.predictor, shape=sigma,
@@ -29,7 +29,7 @@ mdmb_regression_loglike_case <- function(y, linear.predictor,
     }
     #**********************
     # bct regression
-    if (type=="bct"){
+    if (type=='bct'){
         sigma <- beta[ np-1 ]
         lambda <- beta[ np ]
         loglike_case <- dbct_scaled( y, location=linear.predictor, shape=sigma,
