@@ -1,5 +1,5 @@
 ## File Name: mdmb_regression_loglike_logpost.R
-## File Version: 0.25
+## File Version: 0.262
 
 mdmb_regression_loglike_logpost <- function(mod, beta, beta_prior, is_prior, type,
         is_lambda_fixed)
@@ -15,9 +15,9 @@ mdmb_regression_loglike_logpost <- function(mod, beta, beta_prior, is_prior, typ
     parnames <- names(beta)
     np <- length(beta)
     vcov1 <- mdmb_ginv(x=hessian)
-    if ( ( type %in% c("yjt","bct") ) & ( is_lambda_fixed ) ){
+    if ( ( type %in% c('yjt','bct') ) & ( is_lambda_fixed ) ){
         vcov0 <- matrix( 0, nrow=np, ncol=np )
-        vcov0[1:(np-1),1:(np-1)] <- vcov1
+        vcov0[1L:(np-1),1L:(np-1)] <- vcov1
         vcov1 <- vcov0
     }
     #--- output
