@@ -1,5 +1,5 @@
 ## File Name: yjt_regression.R
-## File Version: 0.342
+## File Version: 0.343
 
 
 yjt_regression <- function( formula, data, weights=NULL,
@@ -8,7 +8,7 @@ yjt_regression <- function( formula, data, weights=NULL,
     maxiter=300, control=NULL )
 {
     CALL <- match.call()
-    type <- "yjt"
+    type <- 'yjt'
     #--- wrapping general regression function
     res <- mdmb_regression( formula=formula, data=data, type=type, weights=weights,
                     beta_init=beta_init, beta_prior=beta_prior, df=df,
